/******************************************************************************
		
		Replication file for:

		"When are Women Deployed? Operational Uncertainty and Deployment of 
		Female Personnel to UN Peacekeeping"
		Kajsa Tidblad-Lundholm
		International Peacekeeping
		https://doi.org/10.1080/13533312.2020.1760717
		Last updated: 25 February 2020
		Contact: kajsa.tidblad.lundholm@gmail.com
		
***********************************************************************/

/*To run the do-file you need to install the following:

*1. To generate tables: 
ssc install estout, replace

**********************************************************************/

*** Edit this to reflect your data location
capture cd "C:/path/to/data" 

use "KTL_WAWD_IP_replication.dta", clear
set more off

*********************************************************************
* DESCRIPTIVE STATS REPORTED IN RESEARCH DESIGN SECTION
*********************************************************************
//check number of contributing countries
use "KTL_WAWD_IP_replication.dta", clear
keep country_ipi
duplicates drop
bro 
*125 contributing countries


//check number of missions
use "KTL_WAWD_IP_replication.dta", clear
keep mission
duplicates drop
bro
*24


//check which missions were new during the time period 2009-2015
use "KTL_WAWD_IP_replication.dta", clear
keep if new_mission==1
tab mission

/*     Mission |      Freq.     Percent        Cum.
---------------+-----------------------------------
       MINUSCA |         39       19.21       19.21
       MINUSMA |         36       17.73       36.95
        UNISFA |         26       12.81       49.75
        UNMISS |         55       27.09       76.85
        UNSMIS |         47       23.15      100.00
---------------+-----------------------------------
         Total |        203      100.00 */
		 



use "KTL_WAWD_IP_replication.dta", clear
set more off

*********************************************************************
* FIGURE 1: HISTOGRAM: DISTRIBUTION OF THE DEPENDET VARIABLE
*********************************************************************
hist percent_mil_female_ratio, freq width (1) ytitle("Frequency") xtitle("Proportion of female mil. personnel in TCCs' contributions (%)") title("Distribution of the dependent variable")
*--------------------------------------------------------------


*********************************************************************
* TABLE 1: DESCRIPTIVE STATISTICS OF MAIN VARIABLES + CONTROLS
*********************************************************************
sum mil_female_ratio new_mission duration_year ma5_target_1000 sum2_mission_pk_fat_year_1000 sum2_svac_dummy_gwno chap_VII log_gdp_target mission_size_1000 Laborforcefemaleoftotal mil_total_1000 log_gdp 
*--------------------------------------------------------------

**********************************************************************************
* FIGURE 2: LINE CHART: PERCENT OF WOMEN IN SOME OF THE MISSIONS ACTIVE 2006-2015
**********************************************************************************
**Source: SIPRI Multilateral Peace Operations Database, https://www.sipri.org/databases/pko
*--------------------------------------------------------------


*********************************************************************
* FIGURE 3: ILLUSTRATING THE EFFECT OF NEW MISSION
*********************************************************************
meglm percent_mil_female_ratio i.new_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc : , family(bin) link(logit)
margins, at(new_mission = (0 (1)1)) atmeans
marginsplot, recast(scatter) ciopts(recast(rspike))  xsc(reverse) xlab(-.50 " " 0 "No" 1 "Yes" 1.50 " ") ytitle("Predicted mean of female mil. personnel in a contribution") ///
title("Effect of new mission (logit link)") note("Note: Marginal predicted means with 95% confidence intervals") ///
name (newmission_logit, replace)

meglm percent_mil_female_ratio i.new_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc :
margins, at(new_mission = (0 (1)1)) atmeans
marginsplot, recast(scatter) ciopts(recast(rspike))  xsc(reverse) xlab(-.50 " " 0 "No" 1 "Yes" 1.50 " ") ytitle("Predicted mean of female mil. personnel in a contribution") ///
title("Effect of new mission") note("Note: Marginal predicted means with 95% confidence intervals") ///
name (newmission_notlogit, replace)

graph combine newmission_logit newmission_notlogit, nocopies

/// Descriptives that follows figure 3 in a footnote
sum percent_mil_female_ratio if new_mission==1
sum percent_mil_female_ratio if new_mission==0

*--------------------------------------------------------------


*************************************************************************************
* FIGURE 4: ILLUSTRATING THE EFFECT OF DURTAION (INC DIMINISHING EFFECT OF DURATION)
*************************************************************************************
meglm percent_mil_female_ratio c.duration_year##c.duration_year ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_* || cow_tcc : , family(bin) link(logit)
margins, at(duration_year = (0(1)40)) vsquish atmeans
marginsplot, ytitle("Predicted mean of female mil. personnel in a contribution") title("Effect of mission duration (logit link)") note("Note: Marginal predicted means with 95% confidence intervals") ///
name (duration_logit, replace)
graph display, ysize(5)
*--------------------------------------------------------------



*********************************************************************
* TABLE 2: MIXED EFFECTS GENERALIZED LINEAR MODEL
********************************************************************* 
*** MODEL 1 -> BIVARIATE NEW_MISSION LOGIT
meglm mil_female_ratio new_mission || cow_tcc : , family(bin) link(logit)
estimates store b1

*** MODEL 2 -> NEW_MISSION + CONTROLS LOGIT
meglm mil_female_ratio new_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc : , family(bin) link(logit)
estimates store b2

*** MODEL 3 -> DURATION_YEAR & DURATION2 LOGIT
meglm mil_female_ratio duration_year duration2|| cow_tcc : , family(bin) link(logit)
estimates store b3

*** MODEL 4 -> DURATION_YEAR & DURATION2 LOGIT
meglm mil_female_ratio duration_year duration2 ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc : , family(bin) link(logit)
estimates store b4

*** MODEL 5 -> MILITARY EXPERTS ONLY LOGIT
meglm experts_female_ratio new_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc : , family(bin) link(logit)
estimates store b5

*** MODEL 6 -> MILITARY TROOPS ONLY LOGIT
meglm troops_female_ratio new_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc : , family(bin) link(logit)
estimates store b6

esttab b* using table_2.rtf, replace star(* 0.10 ** 0.05 *** 0.01) se label


// models for footnote about other control variables
meglm mil_female_ratio new_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno ma5_osv_target_1000 western_fcc tcc_mil_total pop_million y_*|| cow_tcc : , family(bin) link(logit)
meglm mil_female_ratio duration_year duration2 ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno ma5_osv_target_1000 western_f tcc_mil_total pop_million y_*|| cow_tcc : , family(bin) link(logit)
*--------------------------------------------------------------


*************************************************************************************
* FIGURE 5: SCATTERPLOT: ILLUSTRATING THE RELATION BETWEEN GENDER EQUALITY AND 
* PROPORTION OF WOMEN IN THE NEW MISSION SETTING
*************************************************************************************
scatter percent_mil_female_ratio Laborforcefemaleoftotal if new_mission==1, ///
ytitle("Proportion of female mil. personnel in TCCs' contributions (%)") ///
xtitle("Percentage share of women in TCCs' labor forces") title("Gender equality and women's participation in new UN missions")
*--------------------------------------------------------------


*********************************************************************
* TABLE 3: EXTENDED ANALYSIS & ROBUSTNESS TEST
********************************************************************* 
*** MODEL 1 -> INTERACTION OLD_MISSION*WOMEN IN LABOR FORCE + CONTROLS
meglm mil_female_ratio old_equal old_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc : , family(bin) link(logit)
estimates store m1

*** MODEL 2 -> INCLUDE FEMFORCES
meglm mil_female_ratio femforces new_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc : , family(bin) link(logit)
estimates store m2

*** MODEL 3 -> EXCLUDE SMALL CONTRIBUTIONS
preserve
drop if mil_total<10
meglm mil_female_ratio new_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000  chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc : , family(bin) link(logit)
estimates store m3
restore

*** MODEL 4 -> ONLY INCLUDING FIRST 10 YEARS OF MIL OPERATION
preserve
drop if duration_year >10
meglm mil_female_ratio new_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc : , family(bin) link(logit)
estimates store m4
restore

*** MODEL 5 -> ONLY INCLUDE MISSIONS THAT STARTED IN 2009 OR AFTER: MINUSCA, MINUSMA, UNISFA, UNMISS, UNSMIS
preserve
keep if mission=="MINUSCA"| mission=="MINUSMA"| mission=="UNISFA"|mission=="UNMISS"|mission=="UNSMIS"
meglm mil_female_ratio new_mission ma5_target_1000 log_gdp_target Laborforcefemaleoftotal mil_total_1000 y_*|| cow_tcc : , family(bin) link(logit)
restore
estimates store m5

*** MODEL 6 -> ONLY INCLUDE MISSIONS THAT STARTED IN 2009 OR AFTER: MINUSCA, MINUSMA, UNISFA, UNMISS, UNSMIS
preserve
keep if mission=="MINUSCA"| mission=="MINUSMA"| mission=="UNISFA"|mission=="UNMISS"|mission=="UNSMIS"
meglm mil_female_ratio new_mission ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc : , family(bin) link(logit)
restore
estimates store m6

esttab m* using table_3.rtf, replace star(* 0.10 ** 0.05 *** 0.01) se label


//exploring descriptives of missions that started in 2009 or after: MINUSCA, MINUSMA, UNISFA, UNMISS, UNSMIS
preserve
keep if mission=="MINUSCA"| mission=="MINUSMA"| mission=="UNISFA"|mission=="UNMISS"|mission=="UNSMIS"
sum mil_female_ratio if new_mission==1
sum mil_female_ratio if new_mission==0
sum mil_female_ratio if duration_year==4
restore
*---------------------------------------------------------------



*********************************************************************
* APPENDIX 4: ADDITIONAL FIGURES AND TABLES
********************************************************************* 

*** TABLE 4: DURATION(YEAR)EXCLUDING THE LOGIT LINK 
meglm mil_female_ratio duration_year duration2 ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp Laborforcefemaleoftotal mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno y_*|| cow_tcc :
estimates store l1

esttab l* using table_appendix.rtf, replace star(* 0.10 ** 0.05 *** 0.01) se label


***FIGURE 6: SCATTERPLOT INCLUDING ALL CONTRIBUTIONS
scatter percent_mil_female_ratio Laborforcefemaleoftotal, ytitle("Proportion of female mil. personnel in TCCs' contributions (%)") xtitle("Percentage share of women in TCCs' labor forces") title("Gender equality and women's participation in UN missions")


*********************************************************************
* APPENDIX 5: EXPLORING WHERE TCCs DEPLOY TO
********************************************************************* 

// exploring if there are systematic differences in where TCC's deploy depending on gender equality
sum percent_mil_female_ratio percent_experts_female_ratio percent_troops_female_ratio new_mission duration_year ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno if Laborforcefemaleoftotal < 41.94312
sum percent_mil_female_ratio percent_experts_female_ratio percent_troops_female_ratio new_mission duration_year ma5_target_1000 sum2_mission_pk_fat_year_1000 log_gdp mil_total_1000 mission_size_1000 chap_VII log_gdp_target sum2_svac_dummy_gwno if Laborforcefemaleoftotal > 41.94312




/***Info to the user about how the DV was created:
IPI provides monthly data (TCC-mission-month), while the unit of analysis the the study is TCC-mission-year).
The IPI does not provide info on "total female military personnel", "total male military personnel" and "total military personnel"
The main DV "mil_female_ratio" was created by:

// create variable for all military women deployed by a TCC in a month
egen mil_female=rowtotal (experts_on_mission_female troops_female)

// create a variable for total number of military staff deployed by a TCC in a month
egen mil_total=rowtotal (experts_on_mission_male experts_on_mission_female troops_male troops_female)

//to get yearly info ("on average, how many did a TCC deploy each month")
bysort cow_tcc mission year:egen mean_mil_female=mean(mil_female)
bysort cow_tcc mission year:egen mean_mil_total=mean(mil_total)
duplicates drop

//to gen the main DV "ratio of female military personnel".
gen mil_female_ratio=mean_mil_female/mean_mil_total



IPI provides montly info on number of female experts, male experts and total experts.
"experts_female_ratio" was created by:

//to get yearly info ("on average, how many experts did a TCC deploy each month")
bysort cow_tcc mission year:egen mean_experts_female=mean(experts_on_mission_female)
bysort cow_tcc mission year:egen mean_experts_total=mean(experts_on_mission_total)
duplicates drop

//to gen the variable "ratio of female experts"
gen experts_female_ratio=mean_experts_female/mean_experts_total



IPI provides montly info on number of female troops, male troops and total troops.
"troops_female_ratio" was created by:

bysort cow_tcc mission year:egen mean_troops_female=mean(troops_female)
bysort cow_tcc mission year:egen mean_troops_total=mean(troops_total)
duplicates drop

//to gen the variable "ratio of female troops"
gen troops_female_ratio=mean_troops_female/mean_troops_total

This means that if a contributor deployed military experts for 5 months and military troops for 4 months 
the mean for "all military personnel" (and military experts) will be calculated as the mean of those 5 months 
while the "military troops" will be calculated as the mean of troops during 4 months. 

